package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````/!4``#0```!0`0$```0`!30`(``'
M`"@`%@`5``8````T````-````#0```#@````X`````0````$`````P```!0!
M```4`0``%`$``!@````8````!`````$````!````````````````````3'\`
M`$Q_```%```````!``$```#,_0``S/T!`,S]`0!P`@``G`(```8```````$`
M`@```-3]``#4_0$`U/T!`/````#P````!@````0```!1Y71D````````````
M```````````````&````$````%+E=&3,_0``S/T!`,S]`0`T`@``-`(```0`
M```!````+VQI8B]L9"UM=7-L+6%R;6AF+G-O+C$`$0```$P````(````"```
M``&0$``E0`2`*(`0!:"&4(2``0``"R`$C3B`$D&*!`@(3````$T```!1````
M5@```%<```!>````7P```&``````````8@```&,`````````9````&4```!H
M```````````````!KS3H:G^:?.K3[P[.WD<M;\7?'R[%F[:XC?$.U&34?'94
M/)0A_^0.V7%8'/JA;&#"Y3\LL@&+;T+ZUX?B1\8!6.^7>;OCDGQ5PSS29Z_,
M9H@'<--#1=7L,V+;[16,)<Q_J9R;X*<""FH:GE"_VE<;H^#[20``````````
M````````````````!!`````````#``<``````````@```````P`1``$`````
M`````````!(````)```````````````1````\P$`````````````$0```'P!
M`````````````!(````0```````````````2````S`$`````````````$@``
M`!@``````````````!(````?```````````````2``````(`````````````
M$@```-@!`````````````!(````H```````````````@````&@,`````````
M````(0```$```````````````!(```!&```````````````2````30``````
M````````$@```-$"`````````````!(```#O`@`````````````2````5```
M````````````$@```#("`````````````!(```!;```````````````2````
MN`(`````````````$@```&(``````````````!(```!J```````````````2
M````R@(`````````````$@```'(``````````````!(```"A`@``````````
M```2````>@``````````````$@```(,``````````````"````#A`@``````
M```````2````GP``````````````$@```*0``````````````!(```"9`0``
M```````````6````OP(`````````````$@```%\"`````````````!(```"K
M```````````````2````40(`````````````$@```%X#`````````````!(`
M```9`P`````````````1````@P(`````````````$@````8#````````````
M`!(````1`@`````````````2````&P,`````````````$0```+(`````````
M`````!(```"[```````````````1````B@$`````````````$@```,T`````
M`````````"(```#<```````````````@````\@``````````````$@```/X"
M`````````````!(```!O`@`````````````2````]P``````````````$@``
M`/T``````````````"````"L`@`````````````2````%P$`````````````
M$@```+T!`````````````!(````<`0`````````````2````D0(`````````
M````$@```"(!`````````````!(```"L`0`````````````2````,`$`````
M````````$@```$$!`````````````!(````M`@`````````````2````/@(`
M````````````$@```$<!`````````````!(```!X`@`````````````2````
MZ`(`````````````$@```-D"`````````````!(```!6`0`````````````2
M````*`(`````````````$@```%T!`````````````!(```!D`0``````````
M```2````&`,`````````````(0```'4!`````````````!(```!>!```:``"
M```````0`!(`$P,``/02``!(`@``$@`)`.T!``!P/0``!````!(`"@"@`P``
M@"4``/@&```2``D`;@0``/0N``!8````$@`)`'T#``#L'@``!````!(`"0`2
M!```!!````0````2``<`PP,``'@L``!\`@``$@`)`!@$```\``(``````!``
M$@!&!```\!X``#`"```2``D`^P,``#P``@``````$``2`(X#``#,)```M```
M`!(`"0"M`P``V!P``%@````2``D`M0,``$PD``!H````$@`)`-D#``#\.@``
M/`$``!(`"0#N`P``("$``"0````2``D`!P0``&@``@``````$``2`&D$``!H
M``(``````!``$@!#`P``8!4``&0````2``D`)@0``$0A``"8`0``$@`)`.0#
M```X``(`!````!$`$0`_!```/``"```````0`!$```0``#P5````````$@`)
M``\$``"L.@``4````!(`"0!,`P``M"0``!@````2``D`9P,``)@=``!4`0``
M$@`)`%,$```X/```.`$``!(`"0!=!```:``"```````0`!(`,@0``-PB``!P
M`0``$@`)``!O<&5N9&ER`'-T9&5R<@!R96%L;&]C`&%C8V5S<P!S;G!R:6YT
M9@!?7V1E<F5G:7-T97)?9G)A;65?:6YF;P!L<V5E:P!G971P:60`<W1R8VUP
M`&UE;7-E=`!U;FQI;FL`;65M;6]V90!S=')N8VUP`'-T<G)C:'(`8VQO<V5D
M:7(`7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`&]P96X`<W1R<W1R`'-T
M<F-H<@!R96%D;&EN:P!?7W-T86-K7V-H:U]G=6%R9`!?7V-X85]F:6YA;&EZ
M90!?7W)E9VES=&5R7V9R86UE7VEN9F\`97AI=`!C;&]S90!?251-7W)E9VES
M=&5R5$U#;&]N951A8FQE`')E860`<FUD:7(`7U]S=&%T7W1I;64V-`!?7V5R
M<FYO7VQO8V%T:6]N`&UK9&ER`%]?;'-T871?=&EM938T`&UE;6-P>0!S=')L
M96X`7U]S=&%C:U]C:&M?9F%I;`!G971U:60`4&5R;%]S>7-?=&5R;0!097)L
M7W-Y<U]I;FET,P!03%]C=7)R96YT7V-O;G1E>'0`4&5R;%]A=&9O<FM?;&]C
M:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N
M=&5X=`!?9FEN:0!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!097)L
M7V-R;V%K7VUE;6]R>5]W<F%P`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L
M7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`
M<&5R;%]R=6X`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`&)O;W1?1'EN84QO
M861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C
M`'-T<F-P>0!R96%D9&ER`'-P<FEN=&8`<W1R9'5P`'-T<G1O:P!P=&AR96%D
M7V%T9F]R:P!F<')I;G1F`%]?;&EB8U]S=&%R=%]M86EN`%]?7V5N=FER;VX`
M;&EB<&5R;"YS;P!L:6)C+FUU<VPM87)M:&8N<V\N,0!?<W1A<G1?8P!G971?
M=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`
M<&%R7V-U<G)E;G1?97AE8P!P87)?<V5T=7!?;&EB<&%T:`!P87)?;6MT;7!D
M:7(`>'-?:6YI=`!P87)?96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?0D]/
M5`!S:&%?=7!D871E`&UY7W!A<E]P;`!P87)?8F%S96YA;64`7U]B<W-?<W1A
M<G0`7U]E;F1?7P!S:&%?:6YI=`!?7V)S<U]S=&%R=%]?`'!A<E]D:7)N86UE
M`'!A<E]I;FET7V5N=@!?961A=&$`<&%R7V9I;F1P<F]G`'-H85]F:6YA;`!?
M7V)S<U]E;F1?7P!?96YD`'!A<E]C;&5A;G5P`"]U<W(O;&EB+W!E<FPU+V-O
M<F5?<&5R;"]#3U)%`,S]`0`7````T/T!`!<```#`_P$`%P```,S_`0`7````
MV/\!`!<```````(`%P````@``@`7````#``"`!<````4``(`%P```!@``@`7
M````'``"`!<````@``(`%P```"0``@`7````+``"`!<````P``(`%P```#@`
M`@`7````Q/\!`!4$``#(_P$`%04``-#_`0`5#0``U/\!`!4>``#<_P$`$R(`
M`.#_`0`5+```Y/\!`!4N``#H_P$`%3```.S_`0`5,0``\/\!`!4V``#T_P$`
M%3L``/C_`0`5/0``_/\!`!5!``#0_@$`%@,``-3^`0`6!@``V/X!`!8'``#<
M_@$`%@@``.#^`0`6"0``Y/X!`!8*``#H_@$`%@L``.S^`0`6#```\/X!`!8-
M``#T_@$`%@\``/C^`0`6$```_/X!`!81````_P$`%A(```3_`0`6$P``"/\!
M`!84```,_P$`%A4``!#_`0`6%@``%/\!`!87```8_P$`%A@``!S_`0`6&0``
M(/\!`!8:```D_P$`%AL``"C_`0`6'```+/\!`!8=```P_P$`%A\``#3_`0`6
M(```./\!`!8A```\_P$`%B,``$#_`0`6)```1/\!`!8E``!(_P$`%B8``$S_
M`0`6)P``4/\!`!8I``!4_P$`%BH``%C_`0`6*P``7/\!`!8M``!@_P$`%B\`
M`&3_`0`6,```:/\!`!8Q``!L_P$`%C(``'#_`0`6,P``=/\!`!8T``!X_P$`
M%C4``'S_`0`6-P``@/\!`!8X``"$_P$`%CD``(C_`0`6.@``C/\!`!8\``"0
M_P$`%CX``)3_`0`6/P``F/\!`!9```"<_P$`%D(``*#_`0`60P``I/\!`!9$
M``"H_P$`%D4``*S_`0`61@``L/\!`!9'``"T_P$`%D@``+C_`0`620``O/\!
M`!9+```!0"WI`4"]Z![_+^$$X"WE!."?Y0[@C^`(\+[EI.X!``#&C^(>RHSB
MI/Z\Y0#&C^(>RHSBG/Z\Y0#&C^(>RHSBE/Z\Y0#&C^(>RHSBC/Z\Y0#&C^(>
MRHSBA/Z\Y0#&C^(>RHSB?/Z\Y0#&C^(>RHSB=/Z\Y0#&C^(>RHSB;/Z\Y0#&
MC^(>RHSB9/Z\Y0#&C^(>RHSB7/Z\Y0#&C^(>RHSB5/Z\Y0#&C^(>RHSB3/Z\
MY0#&C^(>RHSB1/Z\Y0#&C^(>RHSB//Z\Y0#&C^(>RHSB-/Z\Y0#&C^(>RHSB
M+/Z\Y0#&C^(>RHSB)/Z\Y0#&C^(>RHSB'/Z\Y0#&C^(>RHSB%/Z\Y0#&C^(>
MRHSB#/Z\Y0#&C^(>RHSB!/Z\Y0#&C^(>RHSB_/V\Y0#&C^(>RHSB]/V\Y0#&
MC^(>RHSB[/V\Y0#&C^(>RHSBY/V\Y0#&C^(>RHSBW/V\Y0#&C^(>RHSBU/V\
MY0#&C^(>RHSBS/V\Y0#&C^(>RHSBQ/V\Y0#&C^(>RHSBO/V\Y0#&C^(>RHSB
MM/V\Y0#&C^(>RHSBK/V\Y0#&C^(>RHSBI/V\Y0#&C^(>RHSBG/V\Y0#&C^(>
MRHSBE/V\Y0#&C^(>RHSBC/V\Y0#&C^(>RHSBA/V\Y0#&C^(>RHSB?/V\Y0#&
MC^(>RHSB=/V\Y0#&C^(>RHSB;/V\Y0#&C^(>RHSB9/V\Y0#&C^(>RHSB7/V\
MY0#&C^(>RHSB5/V\Y0#&C^(>RHSB3/V\Y0#&C^(>RHSB1/V\Y0#&C^(>RHSB
M//V\Y0#&C^(>RHSB-/V\Y0#&C^(>RHSB+/V\Y0#&C^(>RHSB)/V\Y0#&C^(>
MRHSB'/V\Y0#&C^(>RHSB%/V\Y0#&C^(>RHSB#/V\Y0#&C^(>RHSB!/V\Y0#&
MC^(>RHSB_/R\Y0#&C^(>RHSB]/R\Y0#&C^(>RHSB[/R\Y0#&C^(>RHSBY/R\
MY0#&C^(>RHSBW/R\Y0#&C^(>RHSBU/R\Y0#&C^(>RHSBS/R\Y3!`+>DDT$WB
M'`"-Y1@0C>44((WE&!"-XA0@C>(<`(WBV$&?Y:W__^O4,9_E!$"/X`,PE.<,
M,(WER#&?Y0P@G>4#,)3G`A"@X0,`H.$0,(WE7?__Z[`QG^4#,)3G<$\=[@!0
MT^4``%7C#```&H#__^N8(9_E``!0XP(@C^`,`(+E`0``&@$`H..=___KKO__
MZWPQG^4#,)_G`S"4YWM7P^5P,9_E'`"=Y0,PG^<#()3G`T"`XLXSTN4$`(#B
M`S"#XP<!<./.,\+E````FGW__^L``:#AEO__ZSPAG^4`,*#A`B"/X`0`@N48
M()WE',"=Y0`0DN4`$(#E(!&?Y0$0C^`$$(#E&!&?Y0$0C^``$)'E"!"`Y0P1
MG^4!$(_@#!"@Y0$0H.,!`%SA,```R@``7.,#$(SB$!"@TP$1H,$`(*#CY%"?
MY0$@@^?@$)_E`""-Y050C^`$(*#A#`"5Y0$0C^`T___K`$!0X@(``!H,`)7E
M:?__ZP!`H.&T4)_E!5"/X`P`E>5)___KJ`"?Y0``C^#4``#K``!0XPP``!H(
M,)7E``!3XP,``!J,`)_E``"/X,P``.L(`(7E@#"?Y0,PC^`(`)/E``!0XP``
M``J+!@#K;#"?Y0,PC^`,`)/E>___Z]7^_^L$`*#A)-"-XC"`O>@!X9+G`1"!
MX@3@H.7(___JG.L!`#@!```T`0``!`$``.3L`0!,[`$`..P!`'SL`0":+```
M-.P!`($L```,[`$`V`@``.#K`0`9*@``KBD``*#K`0"(ZP$``+"@XP#@H.,0
M$)_E`1"/X`T`H.$/P,#C#-"@X0```.N$Z`$`'T`MZ4@PG^5(()_E`S"/X`(@
MD^<(((WE/""?Y0(@D^<,((WE`""@XP0@C>4L()_E`C"3YP0@@.(`,(WE`!"0
MY0@PG>4,`)WE`/__ZQ30C>($\)WD4.D!`!0!``#\````"`$``"P`G^4L,)_E
M``"/X`,PC^```%/A(#"?Y0,PC^`>_R\!&""?Y0(PD^<``%/C'O\O`1/_+^%H
MZ@$`9.H!`.#H`0`0`0``.`"?Y3@PG^4``(_@`S"/X``P0^"C'Z#A0Q&!X"0P
MG^7!$+#A`S"/X![_+P$8()_E`C"3YP``4^,>_R\!$_\OX23J`0`@Z@$`D.@!
M`"P!``!H,)_E$$`MZ0,PC^``,-/E7$"?Y0``4^,$0(_@$("]&%`PG^4#,)3G
M``!3XP(```I$,)_E`P"?Y]+^_^O*___K.#"?Y0,PE.<``%/C`@``"BP`G^4`
M`(_@<_[_ZP$@H.,@,)_E`S"/X``@P^40@+WHU.D!`$SH`0`D`0``;.D!``P!
M``"4:```>.D!`#0PG^4T()_E`S"/X`(PD^<``%/C!P``"A!`+>D@$)_E(`"?
MY0$0C^```(_@M?[_ZQ!`O>BZ___JN?__ZM#G`0`H`0``,.D!`#1H``"<,)_E
M\$<MZ0!04.(#,(_@!4"@`2````J(()_E`C"3YP!`D^4``%3C&P``"@&0H.$%
M,*#A`V"@X0$@T^0``%+C/0!2$_K__QH$@*#A!6!&X`APH.$$H)CD``!:XPI`
MH`$-```*!B"@X040H.$*`*#A6/[_ZP``4./T__\:!C#:YST`4^/Q__\:!'!'
MX$=QH.$!8(;B`'")Y09`BN`$`*#A\(>]Z(#G`0`<`0``!T`MZ4P@G^5,,)_E
M`B"/X`,PDN<-$*#A`#"3Y00PC>4`,*#CRO__ZS`@G^4H,)_E`B"/X`,PDN<`
M()/E!#"=Y0(@,^``,*#C````"JO^_^L,T(WB!/"=Y-3F`0`@`0``L.8!`'-`
M+>F0()_ED#"?Y0(@C^`#,)+G`$"@X0`PD^4$,(WE`#"@XPU@H.%T4)_E!5"/
MX`80H.$$`*#AK/__ZP``4.,)```:7""?Y5`PG^4"((_@`S"2YP`@D^4$,)WE
M`B`SX``PH.,*```*B_[_ZS@PG^4`()WE`S"5YP`PD^4",8/@!""3Y0``4N,$
M((/D^___&N;__^H(T(WB<("]Z'#F`0`@`0``4.8!`##F`0`<`0``$$`MZ8@@
MG^6(,)_E`B"/X*#03>(#,)+G#1"@X0!`H.$`,)/EG#"-Y0`PH.-9_O_K``!0
MXP``H!,)```:$#"=Y0\Z`^(*"E/C`0E3$P0``!H"$*#C!`"@X<']_^L0#V_A
MH`*@X3`@G^4H,)_E`B"/X`,PDN<`()/EG#"=Y0(@,^``,*#C````"E?^_^N@
MT(WB$("]Z,#E`0`@`0``8.4!`/!#+>D\(9_E/#&?Y0(@C^`#,)+GI-!-X@!0
M4.(`,)/EG#"-Y0`PH.,1```*`##5Y0``4^,.```*E?W_ZP!P4.(+```*!(&?
MY021G^4(@(_@"9"/X`<`H.&Q_?_K`$!0X@T``!H'`*#ASOW_ZP4`H.$1_O_K
MW""?Y<PPG^4"((_@`S"2YP`@D^6<,)WE`B`SX``PH.,I```**_[_ZQ-`A.((
M$*#A!`"@X9K]_^L``%#CY___"@D0H.$$`*#AE?W_ZP``4./B__\*!0"@X1O^
M_^L`8*#A!`"@X1C^_^L``(;@`@"`XIW]_^L`8*#A:!"?Y00PH.$%(*#A`1"/
MX`;^_^L-$*#A!@"@X>[]_^L!`'#C!@"@X0<```H0,)WE#SH#X@$)4^,#```:
MM/__ZP8`H.'M_?_KQO__ZH7]_^OZ___JI-"-XO"#O>@@Y0$`(`$``"DD```D
M)```L.0!`'\C``#P3RWI`5"@X<`AG^7`,9_E`B"/X`,PDN<4T$WB`#"3Y0PP
MC>4`,*#C`##1Y0!@H.$]`%/C`5"!`@4`H.'G_?_K"!"-X@!PH.$&`*#A^_[_
MZX"1G^4`0%#B"9"/X!$```K>_?_K``!7X28``(H!0$3B`3#5Y```4^,!,.3E
M^___&E0AG^5(,9_E`B"/X`,PDN<`()/E##"=Y0(@,^``,*#C2```"M#]_^LP
M,9_E`Z"9YP"PFN4$,9OG``!3XS(``!H<,9_E`H"$X@,PC^``()/E"(&@X0``
M4N,M```*"!"@X0L`H.$8_?_K``!0XP``BN7B__\*`""@XP`PFN4(0(WE"#"#
MX`0@`^4&,*#A`P"@X0$@T^0``%+C/0!2$_K__QJX,)_E`G"'X@-`F><&`$#@
M``"'X`B`G>4`D)3E+_W_ZP``4.,(`8GGS/__"@`PE.4((9/G`1#6Y`(PH.$]
M`%'C``!1$P`0PN4!((+B^/__&CT@H.,`(,/E`2#5Y```4N,!(./E^___&KS_
M_^H!0(3BQ___Z@$@H.,(`*#A`""#Y1;]_^L`,%#B!#"-Y;/__PH+$*#A""!(
MXA/]_^L$,)WE`#"*Y<K__^H4T(WB\(^]Z+SC`0`@`0``=.,!`$3C`0`<`0``
MF.0!`'#/'>XX,)_E.""?Y0,PC^`",)/G"-!-XBP`G^4$,(WE``"?YR0PG^4D
M$)_E!""=Y0``G.<#,(_@`1"/X`C0C>)=_?_JV.$!`#`!``#<X@$`F&$``/T@
M```30"WI<$\=[D0PG^4#,)_G`P"4Y^/__^L`(*#C-#"?Y30`G^4#,(_@``"?
MYRP0G^4$((WE*""?Y0`PC>4``)3G`B"/X`$0C^"[_/_K"-"-XA"`O>B8X@$`
M-2,``'SB`0"U(`````\``'!`+>DP(9_E,#&?Y0+:3>(8T$WB`B"/X`,PDN<"
M&HWB%!"!X@`PD^4`,('E`#"@X[/\_^L((9_E"&&?Y0(@C^``((WE`"&?Y0Q`
MC>(`,*#A!A"@X00`H.$"((_@F?S_ZP$P@.(&`%/A````FO``\.<!`'#C#```
M&@`PH./,$)_EN""?Y0$0C^`""HWB`B"1YQ0`@.(`$)+E`""0Y0$0,N``(*#C
M(```"B7]_^L!6HWB$%"%X@0`H.$!*J#C!1"@X=K\_^L`0%#BZO__N@$`A.*@
M_/_K`#!0XN;__PH%`%/A`@``*@0@@^`"`%7AWO__.@4`4^$"``":!""%X`(`
M4^'9__\Z!@!4X=?__\H$(*#A`P"@X040H.$`_?_K`""@XP`PH.$$(,#GT___
MZ@,`H.$"VHWB&-"-XG"`O>@0X0$`(`$``'8@```!$```3B```*#@`0"I___J
M\$\MZ?@AG^7X,9_E0MU-X@(@C^`LT$WB`%"@X>@!G^4#,)+G`4"@X4(=C>(`
M`(_@)!"!X@`PD^4`,('E`#"@XRG^_^LO$*#C`&"@X04`H.&._/_K``!0XP\`
M``JL`9_E!1"@X0``C^#D_O_KH"&?Y9`QG^4"((_@0AV-X@,PDN<D$('B`""3
MY0`PD>4"(#/@`#"@XU8```K3_/_K!`"@X6O\_^ML$9_E;'&?Y0$0C^"^_/_K
M`$"@X6"!G^5@D9_E!W"/X`B`C^`)D(_@``!4X^'__PH`,-3E``!3XP=`H`$`
M`%;C!```"@00H.$&`*#A,/S_ZP``4.,W```*!`"@X;;\_^L`$*#C`3!`X@,P
MA.`#`%3A`@``*@`@T^4O`%+C%0``"@0`H.&L_/_K`*"@X04`H.&I_/_K`*"*
MX`&@BN(!"EKCQ/__*JBPC>($H$OB!#"@X0@@H.$!&J#C"@"@X010C>4`D(WE
M`/S_ZP$`@.(!"E#C`@``FO``\.<!$$/DXO__Z@H`H.$($(WB=?S_ZP``4.,0
M```:D#`;Y0\Z`^(""5/C#```&@$0H.,*`*#AZ_O_ZP``4.,'```:9`"?Y0H0
MH.$``(_@C/[_ZPH`H.$?_/_K`%"@X:/__^I($)_E``"@XP$0C^!P_/_K`$"@
MX;7__^H%`*#A0MV-XBS0C>+PC[WHO-\!`"`!```R'P```Q\``%C?`0#('@``
M51X``'X?``"N'@``HQT``)`=```00"WI+Q"@XP!`H.'[^__K``!0XP%`@!($
M`*#A$$"]Z/_[_^HP0"WI<"&?Y7`QG^4!VDWB`B"/X`S03>(!&HWB`S"2YP!0
M4.($$('B`#"3Y0`P@>4`,*#C`@``"@`PU>4``%/C$0``&C@AG^4P,9_E`B"/
MX`$:C>(#,)+G!!"!X@`@D^4`,)'E`B`SX``PH.,````*2/S_ZPP!G^4``(_@
M`=J-X@S0C>(P0+WHW/O_ZC[\_^L!`(#B`0I0XS4``(H$0(WB!1"@X00`H.'(
M^__K!`"@X37\_^L`(*#C`0!`X@``A.`$`%#A`@``F@`PT.4O`%/C$@``"B\0
MH.,$`*#AOOO_ZP``4.,/```:G""?Y8PPG^4"((_@`1J-X@,PDN<$$('B`""3
MY0`PD>4"(#/@`#"@X];__QIT`)_E``"/X-;__^H!($#DY?__Z@0`4.$`,*"#
M`##`A00`H.&P^__K4""?Y3@PG^4"((_@`1J-X@,PDN<$$('B`""3Y0`PD>4"
M(#/@`#"@X\'__QH!VHWB#-"-XC"`O>@``*#C[___ZFC=`0`@`0``+-T!`$D<
M``"(W`$`J1L``#3<`0`8`9_E$$`MZ0``C^!4_?_K#`&?Y0Q!G^4``(_@4/W_
MZP0!G^4$0(_@``"/X$S]_^OX`)_E``"/X$G]_^OP`)_E``"/X$;]_^OH`)_E
M``"/X$/]_^O@`)_E``"/X$#]_^O8`)_E``"/X#W]_^L$`*#A._W_Z\@`G^4`
M`(_@./W_Z\``G^4``(_@-?W_Z[@`G^4``(_@&?W_ZP`04.(!```*!`"@X=K]
M_^N@`)_E``"/X!+]_^L`$%#B`@``"I``G^4``(_@TOW_ZX@`G^4``(_@"OW_
MZP`04.((```*>`"?Y0``C^#*_?_K$$"]Z&P0G^5L`)_E`1"/X```C^#$_?_J
M8`"?Y0``C^#\_/_K`!!0XO3__PI0`)_E``"/X/#__^J$&P``?1L``*\;``!U
M&P``<AL``&T;``!Q&P``&AL``&4;``!E&P``]QH``%<;``!,&P``2AL``$D;
M``"2&@``0AL``+4:```A&P``L1H``!!`+>E,,)_E`S"/X``PD^4!`'/C#```
M&CP`G^4``(_@VOS_ZP``4.,$```*``#0Y3``4.,``%`3`0"@$P``H`,8,)_E
M`S"/X```@^40,)_E`P"?YQ"`O>BHVP$`/1H``&S;`0!@VP$`$$`MZ8K[_^LU
M^__K``!0XP``D!40@+WH]T`MZ9APG^4`0*#A!W"/X`<`H.&]_/_K`%!0X@00
MH.$"```*`##5Y0``4^,$```:<`"?Y0``C^`,T(WB\$"]Z'?]_^H1^__K``!0
MXQ(``!H$`*#A:OO_ZP!@H.$%`*#A9_O_ZP``AN`"`(#B[/K_ZP!@H.$P,)_E
M,!"?Y00@H.$!$(_@`%"-Y0,PC^!3^__K!A"@X0<`H.'F___J#-"-XO"`O>@\
M&@``%!H``!`9``#F&0``\$\MZ60FG^5D-I_E@=Q-XB303>("((_@6,:?Y0,P
MDN>!'(WB$DZ-X@S`C^``,)/E'#"!Y0`PH.-T,$3B$%",XES@1.(<$('B`&"@
MX0<`G.D'`(/H#P"UZ`\`KN@#`)7H:#!$XBC`C.(#`([H!P"<Z`<`@^@`!I_E
M`':?Y0``C^!U_/_K`%!0X@=PC^`4```*`##5Y0``4^,1```*JO__Z]PEG^7(
M-9_E`B"/X($<C>(#,)+G'!"!X@`@D^4`,)'E`B`SX``PH.,````*(OO_ZP4`
MH.&!W(WB)-"-XO!/O>BW^O_JDO__ZP!04.)H@$0"9@``"@4`H.$4^__K@`"@
MX0$`@.*9^O_K`)"@X0"`H.%PI9_E`5!%X@J@C^`!(/7E``!2XU\``!I<@$3B
M!%"8Y```5>,,```*!0"@X4;\_^L`4%#B^/__"@`PU>4``%/C]?__"H7\_^L`
M`%#C\O__"@4`H.&6^O_K`%"@X72@1.(``%7C!0``&@2`FN0``%CC50``"@`P
MV.4``%/C2@``&@4`H.'M^O_K`*"@X0D`H.'J^O_K`*"*X`&KBN($H(KB"@"@
MX6WZ_^L`@*#AR#2?Y<@4G^4#,(_@`#"-Y<`TG^4%(*#A`S"/X`$0C^`$D(WE
MT?K_ZP<=H.,(`*#AO_K_ZP$`<.,Z```:N?K_ZP`PD.41`%/C-@``"H@DG^6(
M%)_E`@"7YP`PC>4`();E"#"@X0``D.4!$(_@E?K_ZP!0H.-H))_E.#2?Y0(@
MC^"!'(WB`S"2YQP0@>(`()/E`#"1Y0(@,^``,*#CF___&@4`H.&!W(WB)-"-
MXO"/O>CZ^__K`#!0X@4```H`,-/E``!3XP(```I.^O_K`%!0XIC__QH$`)CD
M``!0X_/__QH`5)_E!5"/X)+__^H(`*#A"A"@X9WZ_^L"@(CBE___Z@@`H.$J
M_/_K``!0XZK__PH(`*#A._K_ZP!0H.&D___J"%"@X:K__^H(`*#A$!"-XH7Z
M_^L`D%#B`P``&@`Q%.4/.@/B`0E3XP@```J(,Y_EE!.?Y0,`E^<`();E"#"@
MX0$0C^```)#E5OK_Z[___^KX4!3EC/K_ZP``5>'R__\:`#$4Y8,[H.&C.Z#A
M!PU3X^W__QH*`*#A!?K_ZP!0H.%(`Y_E``"/X+S[_^L`$%#B80``&@!PEN4'
M`*#A=/K_ZP,`4.,`H*#A&@``FB`3G^4$`$#B`1"/X```A^#B^?_K``!0XQ,`
M`!H$`%KC`P``"@J@A^`%,%KE+P!3XPT``!H$8);E``!6XPH```H&`*#A7_K_
MZP,`4.,&``":U!*?Y00`0.(!$(_@``"&X,[Y_^L``%#C!G"@`;3^_^L`H%#B
M<@``&@H0H.$'`*#A\/G_ZP!@4.)M```*`I"@XP`PX.,1(.#C`)"-Y01P1.*X
M^?_K!B"@XP<0H.$&`*#A'?K_ZP0P5.4``%/C,```&@,P5.5#`%/C+0``&@(P
M5.5!`%/C*@``&@$P5.5#`%/C)P``&@`PU.5(`%/C)```&@$PU.5%`%/C(0``
M&@`PX.,Y(.#C!@"@X0"0C>6=^?_K*2"@XP<0H.$&`*#A`OK_ZP@@H.$$,I_E
M!!*?Y0,PC^`$,(WE_#&?Y0!PC>4#,(_@`1"/X`4`H.$5^O_K"`"@X0?Z_^O@
M`9_E!1"@X0``C^`@_/_K!0"@X97^_^M-___J``"6Y1O]_^L`<%#BFO__&IC_
M_^H`,*#C`""@XP`PC>4&`*#A`#"@XWKY_^L`!`#K`)"@X0(IH.,'$*#A!@"@
MX=WY_^L`(%#B'0``R@8`H.%$8$3BTOG_ZS!P1.()$*#A!@"@X54$`.L'D*#A
M7+&?Y0NPC^`'`*#A"Q"@X0$@UN0!H(KBZOG_ZQ0`6N,"<(?B]___&@`PH.,(
M,$3E,#&?Y3`1G^4#,(_@!#"-Y2@QG^4((*#A`)"-Y0,PC^`!$(_@P___Z@<0
MH.$)`*#A[`,`Z]?__^H$$9_E!`&?Y0$0C^```(_@X_O_ZTWY_^OT,)_E]!"?
MY0,PC^`)`(WH[#"?Y0@@H.$%`*#A`S"/X`$0C^#'^?_KV$"?Y=A@G^78<)_E
M!$"/X`9@C^`'<(_@!QV@XP4`H.&O^?_K`0!PXZ;__QJI^?_K`#"0Y1$`4^.B
M__\:,_G_ZP&0B>(!`HWH!#"@X0@@H.$&$*#A!0"@X0APC>6O^?_K[/__ZBC9
M`0`@`0``5-H!`%(8``"TV`$`E-@!`),8``#U%P``V!<``!(7`````0``FA<`
M``37`0`$%P``W18``#\6``"\%@``<18``%46``".%0``(A0``.H3``!#%```
M;14``*(4```V$P``OA,``$T3```=%0``810``.82``#.$@``5Q0``.D4``!P
M0"WI<$\=[A`RG^40`I_E`S"?YP``C^`#,)3G9"#3Y64@P^7.^O_K``!0XP4`
M``H`,-#E,0!3XP(``!H!,-#E``!3XP````J%_?_KU`&?Y=01G^4``)_G`S"@
MXP$@H.,``)3G`1"/X"/Y_^L`4%#B$```"K0QG^4,$)7E`S"?YZPAG^4`$)'E
M`P"4YP(@C^`?^?_K##"5Y0`0D^4(,)'E`043XP,```J(,9_E`S"?YP,`E.?I
M^/_K?`&?Y7P1G^4``)_G`S"@XP$@H.,``)3G`1"/X`CY_^L`8%#B%P``"EP!
MG^4``(_@G?K_ZP`@4.(&```*3#&?Y0P0EN4#,)_G`!"1Y0,`E.<!^?_K"P``
MZ@+\_^L`4%#B#!"6Y2D```HD,9_E!2"@X0,PG^<`$)'E`P"4Y_;X_^L%`*#A
M,/G_ZP@QG^4($9_E`S"?YP$@H.,#4)3G`1"/X`4`H.&;^/_K\""?Y0`0H.$"
M((_@!0"@X>?X_^L`(*#CW#"?Y=P`G^4#,)_G``"/X`,PE.?00)_E92##Y7+Z
M_^L$0(_@``!0XP@`A.4.```:!`"4Y=7]_^L``%#C"`"$Y0D``!JD`)_E``"/
MX(WX_^N<,)_E`S"/X`0@D^64,)_E`""2Y0,PG^?&___JB$"?Y0<=H.,$0(_@
M"`"4Y?_X_^L!((#B$0!0XP$`4A,`,*#A<("]F&0`G^4&`)3I``"/X``0D>5W
M^/_K3-,!`/T1```(TP$`*!,``.#2`0`"$P``L-(!`)S2`0##$@``^Q```&#2
M`0`TT@$`%-(!`$$2``!"$@``W-$!`%(0``!`T@$`\!$```S2`0"`T0$`[-$!
M`+T1``!P0"WI`$"@X9#\_^N&_/_K`%"@X4_]_^L``%#C``!4$W"`O0@`,-3E
M``!3XW"`O0@<$)_E!0"@X0$0C^")^/_K``!5X7"`O1@$`*#A<$"]Z)'Z_^H-
M$```\$\MZ3@KG^4X.Y_E`B"/X%/?3>(#,)+G!""-X@+`H.$`,)/E1#&-Y0`P
MH.-<X(#B'#"`X@00D^0Q'[_F`P!>X000C.3Z__\:$,"@XP(0H.$@X)'E-#"1
MY0'`C.(.,"/@"."1Y0`0D>4.,"/@`3`CX`0@@N+C/Z#A4`!<XSPP@N7Q__\:
MP#J?Y020G>408)#EV$#`X0.0B>`%("3@@$"0Z`:0B>`.(`+@!2`BX.>=B>`"
MD(G@"""=Y6X1).`'$`'@`R""X`4@@N`$$"'@9\&@X0(0@>`,()WE;H$LX`F`
M".`#((+@!"""X!"@G>5N@2C@Z1V!X`*`B.!I(2S@`2`"X`.@BN#AC8C@;J&*
MX&$1H.$4L)WE#"`BX`H@@N!IH2'@`["+X`B@"N`,P(O@::$JX!BPG>7H+8+@
M#*"*X&C!(>`#L(O@`L`,X.*MBN!ID8O@8B&@X1RPG>4!P"S@"<",X&B1(N`#
ML(O@"I`)X`$0B^!HD2G@(+"=Y>K-C.`!D(G@:A$BX`.PB^`,$`'@[)V)X&B!
MB^!LP:#A)+"=Y0(0(>`($('@:H$LX`.PB^`)@`C@`B"+X&J!*.`HL)WEZ1V!
MX`*`B.!I(2S@`["+X`$@`N#AC8C@:J&+X&$1H.$LL)WE#"`BX`H@@N!IH2'@
M`["+X`B@"N`,P(O@::$JX#"PG>7H+8+@#*"*X&C!(>`#L(O@`L`,X.*MBN!I
MD8O@8B&@X32PG>4!P"S@"<",X&B1(N`#L(O@"I`)X`$0B^!HD2G@.+"=Y>K-
MC.`!D(G@:A$BX`.PB^`,$`'@[)V)X&B!B^!LP:#A/+"=Y0(0(>`($('@:H$L
MX`.PB^`)@`C@`B"+X&J!*.!`L)WEZ1V!X`*`B.!I(2S@`["+X`$@`N#AC8C@
M:J&+X&$1H.%$L)WE#"`BX`H@@N!IH2'@`["+X`B@"N`,P(O@::$JX$BPG>7H
M+8+@#*"*X&C!(>`#L(O@`L`,X.*MBN!ID8O@8B&@X4RPG>4!P"S@"<",X&B1
M(N`#L(O@"I`)X`$0B^!HD2G@`9")X%`0G>7JS8S@:K$BX`RP"^`#,('@:#&#
MX`*P*^!4@)WE`["+X!0XG^7LG8G@;!&@X0.`B.!8P)WE`H"(X&HA(>`)("+@
M`\",X.F]B^`"@(C@:L&,X&DA(>!<H)WE"R`BX`+`C.`#H(K@:R&@X>N-B.`!
MH(K@:1$BX`@0(>`!H(K@8!"=Y>C-C.`#$('@:1&!X&B1(N`,D"G@"1"!X&20
MG>7LK8K@`Y")X&S!H.$"D(G@:"$LX`H@(N`"D(G@:""=Y>H=@>`#((+@:"&"
MX&J!+.`!@"C@""""X&R`G>7AG8G@`X"(X&$1H.$,@(C@:L$AX`G`+.`,@(C@
M<,"=Y>DM@N`#P(S@:L&,X&FA(>`"H"K@"L",X'2@G>7BC8C@`Z"*X&(AH.$!
MH(K@:1$BX`@0(>`!H(K@>!"=Y>C-C.`#$('@:1&!X&B1(N`,D"G@"1"!X'R0
MG>7LK8K@`Y")X&S!H.$"D(G@:"$LX`H@(N`"D(G@@""=Y>H=@>`#((+@:"&"
MX&J!+.`!@"C@""""X(2`G>7AG8G@`X"(X&$1H.$,@(C@:L$AX`G`+.`,@(C@
MB,"=Y>DM@N`#P(S@:L&,X&FA(>`"H"K@"L",X(R@G>7BC8C@`Z"*X&(AH.$!
MH(K@:1$BX`@0(>`!H(K@D!"=Y>C-C.`#$('@:1&!X&B1(N`,D"G@"1"!X)20
MG>7LK8K@`Y")X&S!H.$"D(G@:"$LX`H@(N`"D(G@F""=Y>H=@>`#((+@:"&"
MX&J!+.`!@"C@""""X)R`G>7AG8G@`X"(X&$1H.$,@(C@:L$AX`G`+.`,@(C@
MH,"=Y>DM@N`#P(S@:3$AX.*-B.`","/@8B&@X6K!C.!IH8+A`\",X`B@"N!I
M,0+@I+"=Y0.@BN&D-9_EZ,V,X`.PB^`!$(O@`:"*X&@1@N%HL0+@#!`!X`L0
M@>&HL)WE[*V*X`.PB^!LP:#A:9&+X`D0@>!HD8SA:+$,X`J0">`+D(GAK+"=
MY>H=@>`#L(O@`B"+X`*0B>!J(8SA:K$,X`$@`N`+((+AL+"=Y>&=B>`#L(O@
M81&@X6B!B^`(((+@:H&!X6JQ`>`)@`C@"X"(X;2PG>7I+8+@`["+X`S`B^`,
M@(C@:<&!X6FQ`>`"P`S@"\",X;BPG>7BC8C@`["+X&(AH.%JH8O@"L",X&FA
M@N%IL0+@"*`*X`N@BN&\L)WEZ,V,X`.PB^`!$(O@`:"*X&@1@N%HL0+@#!`!
MX`L0@>'`L)WE[*V*X`.PB^!LP:#A:9&+X`D0@>!HD8SA:+$,X`J0">`+D(GA
MQ+"=Y>H=@>`#L(O@`B"+X`*0B>!J(8SA:K$,X`$@`N`+((+AR+"=Y>&=B>`#
ML(O@81&@X6B!B^`(((+@:H&!X6JQ`>`)@`C@"X"(X<RPG>7I+8+@`["+X`S`
MB^`,@(C@:<&!X6FQ`>`"P`S@"\",X="PG>7BC8C@`["+X&(AH.%JH8O@"L",
MX&FA@N%IL0+@"*`*X`N@BN'4L)WEZ,V,X`.PB^`!$(O@`:"*X&@1@N%HL0+@
M#!`!X`L0@>'8L)WE[*V*X`.PB^!LP:#A:9&+X`D0@>!HD8SA:+$,X`J0">`+
MD(GAW+"=Y>H=@>`#L(O@`B"+X`*0B>!J(8SA:K$,X`$@`N`+((+AX+"=Y>&=
MB>`#L(O@81&@X6B!B^!JL8'A""""X`FP"^!J@0'@"+"+X>2`G>7I+8+@`X"(
MX`S`B.!I@8'A#+"+X`*`".!IP0'@#("(X>C`G>7BO8O@`\",X&(AH.%JP8S@
M::&"X0R`B.`+H`K@:<$"X`R@BN'LP)WEZXV(X`/`C.`!$(S@:\&"X0&@BN`(
MP`S@:Q$"X`'`C.'P$)WEZ*V*X`,P@>!I,8/@`\",X/00G>7`,I_E:(&@X0,0
M@>`"(('@:Q$HX`H0(>`!((+@^!"=Y>K-C.!JD2C@`Q"!X`R0*>!K$8'@"1"!
MX/R0G>7L+8+@`Y")X&S!H.$(D(G@:H$LX`*`*.`(D(G@`(&=Y>(=@>`#@(C@
M:H&(X&*A+.`!H"K@"H"(X`2AG>7AG8G@`Z"*X&$1H.$,H(K@8L$AX`G`+.`,
MH(K@",&=Y>F-B.`#P(S@8L&,X&DA(>`(("+@Z*V*X`+`C.!H(:#A#(&=Y12Q
MG>4#@(C@`8"(X&D1(N`*$"'@`8"(X!`1G>7JS8S@`Q"!X&D1@>!JD2+@[(V(
MX`R0*>`#L(O@;,&@X0*PB^!J(2S@""`BX`*PB^`8(9WE"1"!X.@=@>!HD2S@
M`R""X`&0*>!J(8+@"2""X!R1G>7AO8O@`Y")X&$1H.$,D(G@:,$AX`O`+.`,
MD(G@(,&=Y22AG>4#P(S@ZRV"X&C!C.!K@2'@XIV)X`*`*.`#H(K@8B&@X0&@
MBN!K$2+@"1`AX`&@BN`H$9WE",",X.G-C.!I@2+@`Q"!X`R`*.!K$8'@"!"!
MX"R!G>7LK8K@`X"(X&S!H.$"@(C@:2$LX`H@(N`"@(C@,"&=Y>H=@>`#((+@
M:2&"X&J1+.`!D"G@"2""X#21G>7AC8C@`Y")X&$1H.$,P(G@:I$AX`B0*>`)
MP(S@.)&=Y>@M@N`#D(G@:I&)X&BA(>`"H"K@"I")X#RAG>7BS8S@`Z"*X&(A
MH.$!$(K@:*$BX`R@*N`*$('@0*&=Y>R=B>`#,(K@!S"#X&QQ(N!H,8/@"7`G
MX.D=@>`',(/@X3V#X`)@AN!@()_E`#"`Y0'@CN!`,)_E:4&$X&Q1A>`"((_@
M!."`Y0A`@.4,4(#E$&"`Y0,PDN<`()/E1#&=Y0(@,^``,*#C````"A3V_^M3
MWXWB\(^]Z&3/`0`@`0``F7F"6J'KV6[<O!N/UL%BRF3$`0`00"WI8`"@XXWU
M_^LH$)_E*""?Y2C`G^4HX)_E!E"`Z"0@G^40((#E`""@XQ0@@.48((#E7""`
MY1"`O>@!(T5GB:O-[_[<NIAV5#(0\.'2P_!!+>D"8*#A`%"@X10PD.6"(:#A
M`C"3X!@@D"44,(#E`2""(A@@@"48,)#E`4"@X:8^@^`8,(#E7`"0Y1R`A>(`
M`%#C&0``"D!P8.(&`%?A``"(X`9PH*$!`%#A`P``*@<P@.`#`%'A!```*O``
M\.<',('@`0``F@,`4.'Y___J!R"@X000H.'+]?_K7#"5Y0,PA^!``%/C7#"%
MY?"!O1@%`*#A!V!&X`=`A.#G_/_K7'"%XC\`5N,*``#*"`!4X1D``)H&,(C@
M`P!4X>;__SH&(*#A!!"@X0@`H.&V]?_K7&"%Y?"!O>@(`%3A0#"$X@H``)H'
M`%3AV___.@@@H.$$$)3D`P!4X000@N3[__\:!0"@X4!@1N+,_/_KY/__ZO7_
M_RH#`%CA\O__ZN?__RH&,(3@`P!8X>/__^KP02WI'("!XA0PD>488)'E`4"@
MX7\0X.,S?[_FHS&@X3\P`^(!((/B.`!2XP!0H.$#$,CG`@"(X``0H-,V;[_F
M."!BT@<``-H`$*#C0"!BX@_U_^L$`*#AK?S_ZS@@H.,`$*#C"`"@X0GU_^L$
M`*#A]&7$X:;\_^L#,-3E!`"@X0`PQ>6R,-3A`3#%Y0`PE.4C-*#A`C#%Y0`P
ME.4#,,7E!S#4Y00PQ>6V,-3A!3#%Y00PE.4C-*#A!C#%Y00PE.4',,7E"S#4
MY0@PQ>6Z,-3A"3#%Y0@PE.4C-*#A"C#%Y0@PE.4+,,7E#S#4Y0PPQ>6^,-3A
M#3#%Y0PPE.4C-*#A#C#%Y0PPE.4/,,7E$S#4Y1`PQ>6R,=3A$3#%Y1`PE.4C
M-*#A$C#%Y1`PE.43,,7E\$&]Z$+U_^H!0"WI`4"]Z![_+^$]````0`````L`
M``!`````$````$`````F````0````#4```!``````P```$`````&````0```
M`!0```!`````#@```$`````-````0````"4```!`````$@```$`````H````
M0`````(```!`````&````$`````)````0`````H```!````````````````N
M+@`E<R\E<P!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS
M.CI005(Z.D)/3U0`+W!R;V,O)6DO)7,`97AE`%!!4E]414U0`%!!4E]04D]'
M3D%-10`Z`"\`4$523#5,24(`4$523$Q)0@!015),-4]05`!015),24\`4$%2
M7TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!005)?1$5"54<`
M4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!3%]435!$25(`
M4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@`Q
M`$Q$7TQ)0E)!4EE?4$%42`!365-414T`)3`R>``E<R5S)7,E<P!P87(M`"5S
M.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@
M*&5R<FYO/25I*0H`)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N
M<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I
M;VXI"@!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E
M<R5S=&5M<"TE=2TE=25S`!@`<&5R;``P`%!!4CHZ4&%C:V5R.CI615)324].
M`#$N,#4V`%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y`"5S.B!C
M<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL
M960@*&5R<FYO/25I*0H`+64`+2T`55-%4@!54T523D%-10!414U01$E2`%1-
M4``O=&UP`&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D
M0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C
M:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1&24Q%7V]F9G-E=%]S
M:7IE+"`D0T%#2$5?;6%R:V5R+"`D8V%C:&5?;F%M95]S:7IE*3L*0D5'24X@
M>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PHD1DE,15]O9F9S971?<VEZ
M92`](#0[("`@(R!P86-K*").(BD*)&-A8VAE7VUA<FME<B`](")<,$-!0TA%
M(CL*)&-A8VAE7VYA;65?<VEZ92`](#0P.PI]"G-U8B!F:6YD7W!A<E]M86=I
M8PI["FUY("@D9F@I(#T@0%\["FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T
M.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1F:#L*;7D@)'!O<R`]("1S:7IE
M("T@)'-I>F4@)2`D8VAU;FM?<VEZ93L@("`@("`C($Y/5$4Z("1P;W,@:7,@
M82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ90IW:&EL92`H)'!O<R`^/2`P*2![
M"G-E96L@)&9H+"`D<&]S+"`P.PIR96%D("1F:"P@)&)U9BP@)&-H=6YK7W-I
M>F4@*R!L96YG=&@H)%!!4E]-04=)0RD["FEF("@H;7D@)&D@/2!R:6YD97@H
M)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I('L*)'!O<R`K/2`D:3L*<F5T=7)N
M("1P;W,["GT*)'!O<R`M/2`D8VAU;FM?<VEZ93L*?0IR971U<FX@+3$["GT*
M;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A
M8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I
M;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL
M93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE
M*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?
M=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_
M(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M
M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY
M("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8
M)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3
M549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE
M(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W
M:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF
M(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q
M"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO
M<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F
M:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T
M<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L
M96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ
M4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0[
M"F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!
M4E]$14)51WT["FUY("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@
M+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^
M("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L
M:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I
M+`HI.PI?<V5T7W!R;V=N86UE*"D["F]U=',H<7%;7"1P<F]G;F%M92`]("(D
M<')O9VYA;64B72D["E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM0
M05)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D["FUY("@D<W1A<G1?<&]S
M+"`D9&%T85]P;W,I.PI-04=)0SH@>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]
M('-U8B![?3L*=6YL97-S("AO<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE
M*2!["F]U=',H<7%;0V%N)W0@<F5A9"!F<F]M(&9I;&4@(B1P<F]G;F%M92)=
M*3L@(",@9&]N)W0@=7-E("0A(&AE<F4@87,@:70@<F5Q=6ER97,@17)R;F\N
M<&T*;&%S="!-04=)0SL*?0IM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G
M:6,H*E]&2"D["FEF("@D;6%G:6-?<&]S(#P@,"D@>PIO=71S*'%Q6T-A;B=T
M(&9I;F0@;6%G:6,@<W1R:6YG("(D4$%27TU!1TE#(B!I;B!F:6QE("(D<')O
M9VYA;64B72D["FQA<W0@34%'24,["GT*;W5T<R@B1F]U;F0@4$%2(&UA9VEC
M(&%T('!O<VET:6]N("1M86=I8U]P;W,B*3L*<V5E:R!?1D@L("1M86=I8U]P
M;W,@+2`D1DE,15]O9F9S971?<VEZ92P@,#L*<F5A9"!?1D@L("1B=68L("1&
M24Q%7V]F9G-E=%]S:7IE.PIM>2`D;V9F<V5T(#T@=6YP86-K*").(BP@)&)U
M9BD["F]U=',H(D]F9G-E="!F<F]M('-T87)T(&]F($9)3$5S(&ES("1O9F9S
M970B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ
M92`M("1O9F9S970L(#`["B1D871A7W!O<R`]('1E;&P@7T9(.PIM>2`E<F5Q
M=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@
M("`@("`@("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U
M9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D
M8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*
M;W5T<RAQ<5M5;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D
M8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D
M,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\
M*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D
M(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E
M>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D
M9FEL96YA;64@/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE
M.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA
M;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D
M969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?<V%V
M95]A<R@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)
M0CH@)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL
M;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D
M9G5L;&YA;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E
M860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S
M96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@
M(21M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR
M971U<FX@=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D
M=6QE?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B
M.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ
M;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE
M(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I
M.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*
M<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H
M(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL
M97T@/2`D9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA
M;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T
M=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F
M:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A
M9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD[
M"G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D
M>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL
M96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S
M<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@
M>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL
M96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE
M(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E
M7VQI<W1[)&9I;&5N86UE?3L*?0IU;FQE<W,@*"1B=68@97$@(E!+7#`P,UPP
M,#0B*2!["F]U=',H<7%;3F\@>FEP(&9O=6YD(&%F=&5R($9)3$4@<V5C=&EO
M;B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,@.PI]"B1S=&%R
M=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R
M="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D
M;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]21553
M17T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L
M96TI"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P
M=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L
M:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS
M("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D
M05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%2
M7T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@
M<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@
M>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L
M87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]
M"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H
M)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H
M)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2![
M"B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N
M9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q
M.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R
M(&]R(&1I92!Q<5M#86XG="!O<&5N(&QO9R!F:6QE("(D,B(Z("0A73L*?0IE
M;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H
M0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E
M("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$
M:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB
M4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N
M<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E
M<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E
M($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z
M:7`["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\.G)A=R<L
M("1P87(@;W(@9&EE('%Q6T-A;B=T(&9I;F0@<&%R(&9I;&4@(B1P87(B.B`D
M(5T["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI:
M:7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R
M*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@
M<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!A<B)=.PI]"FUY("5M971A7W!A<B`]
M(&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H
M)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A
M(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O
M;6<["GT*?3L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1P:"P@)SPZ
M<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@<F5A9"!P87(@9FEL92`B)'!A
M<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D<&@L("1B=68L(#0["F1I92!Q<5LB
M)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=('5N;&5S<R`D8G5F(&5Q(")02UPP
M,#-<,#`T(CL*8VQO<V4@)'!H.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I
M('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I
M+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B)&]U="(Z
M("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A
M9&5R.PII9B`H9&5F:6YE9"`D9&%T85]P;W,I('L*<F5A9"!?1D@L("1L;V%D
M97(L("1D871A7W!O<SL*?2!E;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*)&QO
M861E<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D
M;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL
M=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<
M)&QO861E<BP@)#`I.PI]"FEF("@D;65T85]P87)[8VQE86Y]*2!["FUY("1P
M87)?8VQE86X@/2`B/3$B.PIM>2`D<&%S<U]P87)?8VQE86X@/2!U8R`B7U]P
M87-S7W!A<E]C;&5A;E]?(CL*)&QO861E<B`]?B!S>R@_/#TD>W!A<W-?<&%R
M7V-L96%N?2DH("LI?0I[)'!A<E]C;&5A;B`N("@B("(@>"`H;&5N9W1H*"0Q
M*2`M(&QE;F=T:"@D<&%R7V-L96%N*2DI?65G.PI]"B1F:"T^<')I;G0H)&QO
M861E<BD*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@;&]A9&5R('1O("(D;W5T
M(CH@)"%=.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!
M4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q
M=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*
M9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z
M.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG
M>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\9RP@<WPO)'Q\(&9O<F5A
M8V@@0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A
M9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?
M97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].R`@("`@("`@(",@6%A8
M(&QI8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E;CL*9F]R96%C:"!M>2`D
M:V5Y("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D9FEL92P@)&YA;64I.PII
M9B`H9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1K
M97E]*2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D9F,I.PI]"F5L<V4@
M>PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1K97D@/7X@;7Q>7%$D
M9&ER7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D,2D[
M"FQA<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO861E<B];7B]=*R\H+BHI)'PI
M('L*:68@*&UY("1R968@/2`D36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@
M)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0II9B`H+68@(B1D:7(O)#$B
M*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]
M"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64["FYE>'0@:68@)'=R
M:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE
M(#U^("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS<')I;G1F*'%Q6U!A8VMI
M;F<@1DE,12`B)7,B+BXN72P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z
M("1F:6QE*2D["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N
M=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;&]C86P@)"\@/2!U;F1E
M9CL*;W!E;B!M>2`D=&@L("<\.G)A=R<L("1F:6QE(&]R(&1I92!Q<5M#86XG
M="!R96%D("(D9FEL92(Z("0A73L*)&-O;G1E;G0@/2`\)'1H/CL*8VQO<V4@
M)'1H.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N="P@
M(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.5GM005)?5D520D%424U](&%N
M9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0
M871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA
M;64I.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K*"=.)RP@;&5N9W1H*"1N
M86UE*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC
M;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL"G!A8VLH)TXG+"!L96YG
M=&@H)&-O;G1E;G0I*2P*)&-O;G1E;G0I"F]R(&1I92!Q<5M%<G)O<B!W<FET
M:6YG(&5M8F5D9&5D($9)3$4@=&\@(B1O=70B.B`D(5T["F]U=',H<7%;5W)I
M='1E;B!A<R`B)&YA;64B72D["GT*?0II9B`H)'II<"D@>PHD>FEP+3YW<FET
M951O1FEL94AA;F1L92@D9F@I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TL*;W(@
M9&EE('%Q6T5R<F]R('=R:71I;F<@>FEP('!A<G0@;V8@(B1O=70B73L*?0HD
M8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@)&-A8VAE7VYA
M;65?<VEZ93L*:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T
M870H)&]U="DI6SE=*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I
M.PIO<&5N(&UY("1T:"P@(CPZ<F%W(BP@)&]U=#L*)&-T>"T^861D9FEL92@D
M=&@I.PIC;&]S92`D=&@["B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T
M.PI]"B1C86-H95]N86UE("X](")<,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M
M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1C86-H95]N86UE("X]("1C86-H95]M
M87)K97(["FUY("1O9F9S970@/2`D9F@M/G1E;&P@*R!L96YG=&@H)&-A8VAE
M7VYA;64I("T@;&5N9W1H*"1L;V%D97(I.PHD9F@M/G!R:6YT*"1C86-H95]N
M86UE+`IP86-K*"=.)RP@)&]F9G-E="DL"B1005)?34%'24,I"B8F("1F:"T^
M8VQO<V4*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@=')A:6QE<B!O9B`B)&]U
M="(Z("0A73L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL
M97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U
M:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E
M<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@
M)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*
M)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E
M;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M
M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@D>FEP+3YR
M96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z
M.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R
M8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ
M92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2
M.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*;W5T<R@B17AT<F%C=&EN
M9R!Z:7`N+BXB*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S
M:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E
M<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E
M8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN
M97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD
M0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG
M>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@
M/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.
M5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M
M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO
M=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A
M9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q
M6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B+BXN
M72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D@
M/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@97AT
M<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE(ET["F-H;6]D*#`U
M-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL
M97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@
M=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER
M(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P
M(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/
M1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B
M($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ
M0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z
M.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER
M92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S
M<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R
M97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A
M9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E
M('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER
M92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E
M<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E
M<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E
M(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE
M.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR
M97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q
M=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I
M<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!
M4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*
M979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T[
M"F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER
M92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE
M.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/
M.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T
M9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[
M4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A
M<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA
M<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-
M4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE
M<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM
M>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P
M=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R
M.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M
M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W
M=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D
M14Y6>U5315)]('Q\("=365-414TG.PI]"FUY("1S=&UP9&ER(#T@(B1P871H
M)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK
M9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM0
M05)?0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["GT*96QS92![
M"F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A
M;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*:68@*"AM>2`D;6%G:6-?<&]S
M(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS965K("1F:"P@)&UA
M9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*"1C86-H95]M
M87)K97(I+"`P.PIM>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@;&5N9W1H*"1C
M86-H95]M87)K97(I.PII9B`H)&)U9B!E<2`D8V%C:&5?;6%R:V5R*2!["G-E
M96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG
M=&@H)&-A8VAE7VUA<FME<BD*+2`D8V%C:&5?;F%M95]S:7IE+"`P.PIR96%D
M("1F:"P@)&)U9BP@)&-A8VAE7VYA;65?<VEZ93L*)&)U9B`]?B!S+UPP+R]G
M.PHD8V%C:&5?9&ER(#T@(F-A8VAE+21B=68B.PI]"GT*8VQO<V4@)&9H.PI]
M"FEF("@A)&-A8VAE7V1I<BD@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PHD
M14Y6>U!!4E]#3$5!3GT@/2`Q.PI]"B1S=&UP9&ER("X]("(D<WES>U]D96QI
M;7TD8V%C:&5?9&ER(CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["B1%3E9[4$%2
M7U1%35!](#T@)'-T;7!D:7(["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@
M)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*
M?0IS=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I
M(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE
M<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE
M+B0D(CL*;7D@)&9H.PHH;W!E;B`D9F@L("<^.G)A=R<L("1T96UP;F%M92D*
M)B8@*'!R:6YT("1F:"`D8V]N=&5N=',I"B8F("AC;&]S92`D9F@I"F]R(&1I
M92!Q<5M%<G)O<B!W<FET:6YG("(D=&5M<&YA;64B.B`D(5T["F-H;6]D("1M
M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP
M;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U
M<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN
M960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@
M/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@
M)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D
M14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R
M;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI("L@,2D[
M"GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE
M+"`D<WES>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L
M("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R
M;V=N86UE)'-Y<WM?97AE?2(I('L*)'!R;V=N86UE("X]("1S>7-[7V5X97T[
M"G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)'-Y<WMP
M871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.
M5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@
M/7X@<R]<421S>7-[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER
M)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(I+"!L87-T*0II9B`M
M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB.PHH*"1P
M<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I
M"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?
M9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!2
M3T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`\
M(#`I('L*)'!R;V=N86UE(#T@(BXD<WES>U]D96QI;7TD<')O9VYA;64B.PI]
M"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C
M=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T
M0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>
M*#\]7"Y<+C]<421S>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?9&5L:6U]+SL*
M)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN
M:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@
M>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#([
M"GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!2
M3T=.04U%("D@*2!["F1E;&5T92`D14Y6>R)005)?)%\B?3L*?0IF;W(@*'%W
M+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[(E!!4E\D7R)]
M(#T@)$5.5GLB4$%27T=,3T)!3%\D7R)](&EF(&5X:7-T<R`D14Y6>R)005)?
M1TQ/0D%,7R1?(GT["GT*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D
M14Y6>U!!4E]#3$5!3GT["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I
M970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E
M('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#
M;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ
M0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C
M:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD[
M"GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<
M)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q
M<5MP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z
M($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P<F]G
M;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO
M7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?
M15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%
M4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2
M(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*`'!E<FQX<VDN8P```#T```!`
M````"P```$`````0````0````"8```!`````-0```$`````#````0`````8`
M``!`````%````$`````.````0`````T```!`````)0```$`````2````0```
M`"@```!``````@```$`````8````0`````D```!`````"@```$``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````.06``!8%@``
M`0```",#```!````+@,```\```!Z!```#`````00```-````<#T``!D```#,
M_0$`&P````0````:````T/T!`!P````$````]?[_;RP!```%````I`@```8`
M```4`@``"@```)@$```+````$````!4``````````P```,3^`0`"````X`$`
M`!0````1````%P```"0.```1````/`T``!(```#H````$P````@````8````
M`````/O__V\!```(^O__;Q``````````````````````````````````````
M````````````````````U/T!````````````$!```!`0```0$```$!```!`0
M```0$```$!```!`0```0$```$!```!`0```0$```$!```!`0```0$```$!``
M`!`0```0$```$!```!`0```0$```$!```!`0```0$```$!```!`0```0$```
M$!```!`0```0$```$!```!`0```0$```$!```!`0```0$```$!```!`0```0
M$```$!```!`0```0$```$!```!`0```0$```$!```!`0```0$```$!```!`0
M```0$```$!```!`0```0$```$!```!`0```0$```$!```!`0```0$```]!(`
M````````````<#T`````````````!!``````````````````````````````
M`````````````````````````@#_____LD````T^````````[CX``.<^``"F
M0```!#\``*Y`````````F$```)U`````````MT```$=#0SH@*$%L<&EN92`Q
M,BXR+C%?9VET,C`R,C`Y,C0M<C0I(#$R+C(N,2`R,#(R,#DR-`!!,@```&%E
M86)I``$H````!39:2P`&!P@!"0$*`A($$P$4`14!%P,8`1H"'`$>!"(!1`$`
M+G-H<W1R=&%B`"YI;G1E<G``+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N
M<F5L+F1Y;@`N<F5L+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE
M:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN86UI8P`N9V]T
M`"YD871A`"YB<W,`+F-O;6UE;G0`+D%232YA='1R:6)U=&5S````````````
M```````````````````````````````````````````+`````0````(````4
M`0``%`$``!@```````````````$`````````$P```/;__V\"````+`$``"P!
M``#H`````P`````````$````!````!T````+`````@```!0"```4`@``D`8`
M``0````#````!````!`````E`````P````(```"D"```I`@``)@$````````
M``````$`````````+0````D````"````/`T``#P-``#H`````P`````````$
M````"````#8````)````0@```"0.```D#@``X`$```,````0````!`````@`
M```_`````0````8````$$```!!````P```````````````0`````````.@``
M``$````&````$!```!`0``#D`@`````````````$````!````$4````!````
M!@```/02``#T$@``?"H`````````````!`````````!+`````0````8```!P
M/0``<#T```P```````````````0`````````40````$````"````?#T``'P]
M``#,00`````````````$`````````%D````!`````@```$A_``!(?P``!```
M````````````!`````````!C````#@````,```#,_0$`S/T```0`````````
M``````0````$````;P````\````#````T/T!`-#]```$```````````````$
M````!````'L````&`````P```-3]`0#4_0``\`````0`````````!`````@`
M``"$`````0````,```#$_@$`Q/X``#P!``````````````0````$````B0``
M``$````#```````"`````0`\```````````````$`````````(\````(````
M`P```#P``@`\``$`+```````````````!`````````"4`````0```#``````
M````/``!`#0```````````````$````!````G0````,``'```````````'``
M`0`S```````````````!``````````$````#``````````````"C``$`K0``
1`````````````0``````````
